==> haskell-crypton-connection-0.3.2-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-connection
version:              0.3.2
visibility:           public
id:                   crypton-connection-0.3.2-AiLIReqiJrmHltLFsWaDuX
key:                  crypton-connection-0.3.2-AiLIReqiJrmHltLFsWaDuX
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  be07d3d233bb3da4d29ea0fe1007f981
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-connection-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-connection-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.3.2-AiLIReqiJrmHltLFsWaDuX
depends:
    base-4.16.4.0 basement-0.0.16-G4nkr58NDViGBBKWcytFlJ
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-x509-1.7.6-3VydbHg0NJyHEZYUaYWl8S
    crypton-x509-store-1.6.9-L3w49La5uDLGE8M5P4BSOy
    crypton-x509-system-1.6.7-4mzRDwOLu4p1376bG4lzuz
    crypton-x509-validation-1.6.12-K8pb5adyCn79KrY5YEhaD3
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    network-3.1.4.0-1FkOptaLhcuI9vN2KGVpMl
    socks-0.6.1-HhC9Imhp9euBeyyqT1klFM tls-1.8.0-FdfQGe59ErpEq4hRrt3G73

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-connection-0.3.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-connection
version:              0.3.2
visibility:           public
id:                   crypton-connection-0.3.2-CiLzgPkdoS4CkiPnFLZ5HE
key:                  crypton-connection-0.3.2-CiLzgPkdoS4CkiPnFLZ5HE
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  fdef2f21235b5e16ec8269a10a105c81
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-connection-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-connection-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.3.2-CiLzgPkdoS4CkiPnFLZ5HE
depends:
    base-4.16.4.0 basement-0.0.16-G4nkr58NDViGBBKWcytFlJ
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-x509-1.7.6-DJ3EWT7lFD0AfddJ26nJKe
    crypton-x509-store-1.6.9-12uKG7R1nXPJQxb1ZZ46k0
    crypton-x509-system-1.6.7-9IZHO1SnVOh6NUKo1iwSlP
    crypton-x509-validation-1.6.12-FZH71C18kU89mhPl5TJZZ0
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    network-3.1.4.0-9VcJfHdcvDFHTEtyJROzpl
    socks-0.6.1-52O3X64He1PL2ZvzqX5gTN tls-1.8.0-6MSSQtWWB9s88tW1WD77BZ

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
